#include <iostream>
#include <string>

#include <idliveface/idliveface.h>

const std::string IDLIVEFACE_HOME = "/opt/idliveface";

void ProcessResult(const idliveface::FaceAnalysisResult& result) {
    std::cout << "Result: " << result << std::endl;

    if (result.status != idliveface::FaceStatus::kInvalid) {
        std::cout << "Image is " << result.status << ", probability is " << *result.genuine_probability << std::endl;
    } else {
        std::cout << "Image did not pass validations and is not suitable for analysis\n"
                  << "Failed validations: " << result.failed_validations << std::endl;
    }
}

int main() {
    try {
        idliveface::Blueprint blueprint(IDLIVEFACE_HOME + "/data");

        std::cout << "Initializing..." << std::endl;
        idliveface::ImageDecoder decoder = blueprint.CreateImageDecoder();
        idliveface::FaceAnalyzer analyzer = blueprint.CreateFaceAnalyzer();

        std::cout << "\nAnalyzing real_face.jpg" << std::endl;
        idliveface::Image image = decoder.DecodeFile(IDLIVEFACE_HOME + "/examples/images/real_face.jpg");
        idliveface::FaceAnalysisResult result = analyzer.Analyze(image);
        ProcessResult(result);

        std::cout << "\nAnalyzing spoof_face.jpg" << std::endl;
        image = decoder.DecodeFile(IDLIVEFACE_HOME + "/examples/images/spoof_face.jpg");
        result = analyzer.Analyze(image);
        ProcessResult(result);

        std::cout << "\nAnalyzing face_is_occluded.jpg" << std::endl;
        image = decoder.DecodeFile(IDLIVEFACE_HOME + "/examples/images/face_is_occluded.jpg");
        result = analyzer.Analyze(image);
        ProcessResult(result);

    } catch (const idliveface::Exception& e) {
        std::cout << "Error: " << e.what() << std::endl;
    }

    return 0;
}
